/*
 * © 2009 David ‘Bombe’ Roden
 */
package net.pterodactylus.arachne.core;

/**
 * Container for a page. A page consists of an {@link Edition} and a path within
 * the edition.
 *
 * @author David ‘Bombe’ Roden <bombe@pterodactylus.net>
 */
public class Page {

	/** The edition of the page. */
	private final Edition edition;

	/** The path of the page. */
	private final String path;

	/**
	 * Creates a new page.
	 *
	 * @param edition
	 *            The edition of the page
	 * @param path
	 *            The path of the page
	 */
	public Page(Edition edition, String path) {
		this.edition = edition;
		this.path = path;
	}

	/**
	 * Returns the edition of the page.
	 *
	 * @return The page’s edition
	 */
	public Edition getSite() {
		return edition;
	}

	/**
	 * Returns the path of the page within the site.
	 *
	 * @return The page’s path
	 */
	public String getPath() {
		return path;
	}

	//
	// OBJECT METHODS
	//

	/**
	 * {@inheritdoc}
	 *
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() {
		return getClass().getName() + "[edition=" + edition + ",path=" + path + "]";
	}

}
